aboutsummaryrefslogtreecommitdiffstats
path: root/src/DatabaseSelection.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'src/DatabaseSelection.hxx')
-rw-r--r--src/DatabaseSelection.hxx5
1 files changed, 2 insertions, 3 deletions
diff --git a/src/DatabaseSelection.hxx b/src/DatabaseSelection.hxx
index 7fab2d303..8ef5b6d9c 100644
--- a/src/DatabaseSelection.hxx
+++ b/src/DatabaseSelection.hxx
@@ -23,7 +23,6 @@
#include "Compiler.h"
#include <assert.h>
-#include <stddef.h>
class SongFilter;
struct Song;
@@ -31,7 +30,7 @@ struct Song;
struct DatabaseSelection {
/**
* The base URI of the search (UTF-8). Must not begin or end
* with a slash. NULL or an empty string searches the whole
* database.
*/
const char *uri;
@@ -46,7 +45,7 @@ struct DatabaseSelection {
DatabaseSelection(const char *_uri, bool _recursive,
const SongFilter *_filter=nullptr)
:uri(_uri), recursive(_recursive), filter(_filter) {
- assert(uri != NULL);
+ assert(uri != nullptr);
}
gcc_pure
@@ -31,7 +30,7 @@ struct Song;
/**
* The base URI of the search (UTF-8). Must not begin or end
- * with a slash. NULL or an empty string searches the whole
+ * with a slash. nullptr or an empty string searches the whole
* database.
*/